@@ -17,7 +17,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-/* $Id: mcrypt.c,v 1.3 2000/10/12 21:06:31 nmav Exp $ */
+/* $Id: mcrypt.c,v 1.4 2000/10/25 18:43:11 nmav Exp $ */
 
 /* Changed by Steve Underwood 1999/12/10 to allow an arbitrary number of 
  * streams of encryption. Currently the resulting code is probably not
@@ -54,7 +54,6 @@ static int internal_init_mcrypt(MCRYPT td, void *key, int lenofkey, void *IV)
 {
 	int *sizes = NULL;
 	int num_of_sizes, i, ok = 0;
-
 	if (lenofkey == 0) {
 		return MCRYPT_KEY_LEN_ERROR;	/* error */
 	}
@@ -174,6 +173,36 @@ void mcrypt_perror(int err)
 	return;
 }
 
+WIN32DLL_DEFINE
+char* mcrypt_strerror(int err)
+{
+char* cerr=malloc(256);
+
+	switch (err) {
+	case MCRYPT_UNKNOWN_ERROR:
+		sprintf(cerr, "Unknown error.\n");
+		break;
+	case MCRYPT_ALGORITHM_MODE_INCOMPATIBILITY:
+		sprintf(cerr,
+			"Algorithm incompatible with this mode.\n");
+		break;
+	case MCRYPT_KEY_LEN_ERROR:
+		sprintf(cerr, "Key length is not legal.\n");
+		break;
+	case MCRYPT_MEMORY_ALLOCATION_ERROR:
+		sprintf(cerr, "Memory allocation failed.\n");
+		break;
+	case MCRYPT_UNKNOWN_MODE:
+		sprintf(cerr, "Unknown mode.\n");
+		break;
+	case MCRYPT_UNKNOWN_ALGORITHM:
+		sprintf(cerr, "Unknown algorithm.\n");
+		break;
+
+	}
+	return cerr;
+}
+
 WIN32DLL_DEFINE
 int mcrypt_free(void *ptr)
 {
