@@ -1,8 +1,28 @@
+/*
+ * Copyright (C) 1998,1999,2000 Nikos Mavroyanopoulos
+ * 
+ * This library is free software; you can redistribute it and/or modify it 
+ * under the terms of the GNU Library General Public License as published 
+ * by the Free Software Foundation; either version 2 of the License, or 
+ * (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
+ */
+
 #include "../../lib/libdefs.h"
 #include "../../lib/mcrypt_modules.h"
 
 /* EBC MODE */
 
+#ifdef USE_LTDL
 #define _init_mcrypt ecb_LTX__init_mcrypt
 #define _end_mcrypt ecb_LTX__end_mcrypt
 #define _mcrypt ecb_LTX__mcrypt
@@ -13,6 +33,7 @@
 #define _mcrypt_get_modes_name ecb_LTX__mcrypt_get_modes_name
 #define _mcrypt_mode_get_size ecb_LTX__mcrypt_mode_get_size
 #define _mcrypt_mode_version ecb_LTX__mcrypt_mode_version
+#endif
 
 int _init_mcrypt( void* ign, void *key, int lenofkey, void *IV, int size)
 {
